Enum googapis::google::bigtable::admin::v2::restore_info::SourceInfo [−][src]
pub enum SourceInfo {
BackupInfo(BackupInfo),
}Expand description
Information about the source used to restore the table.
Variants
BackupInfo(BackupInfo)Information about the backup used to restore the table. The backup may no longer exist.
Tuple Fields of BackupInfo
0: BackupInfoImplementations
pub fn merge<B>(
field: &mut Option<SourceInfo>,
tag: u32,
wire_type: WireType,
buf: &mut B,
ctx: DecodeContext
) -> Result<(), DecodeError> where
B: Buf,